*********************************************************************************************************************************************************
/*
This file uses data.dta to reproduce Tables 2, 3, 4, 5 and 8 of the paper
"Like Father like Sons? The Cost of Sovereign Defaults In Reduced Credit to the Private Sector"

October 2015
For JMCD Editorial
prepared by Rui Esteves and Joao Tovar Jalles*/
*********************************************************************************************************************************************************



*********************************************************************************************************************************************************
***Call dataset
*********************************************************************************************************************************************************

use data.dta
xi i.year
xtset country year


*********************************************************************************************************************************************************
***Table 4 - Reduced-Form Estimates (Fixed Effects Models)
*********************************************************************************************************************************************************


xtreg lktotalrealn dd regc drest dur2n expdecayn i.year , fe robust
outreg2 using table4, ctitle(IV) bdec(3) tdec(3) rdec(3) adec(3) alpha (.01, .05, .1)e(all) word replace
xtreg lktotalrealn dd regc drest dur2n expdecayn  l.ic1 l.icms1 l.gold l.lmp1 l.lmp2 l.ps1 igbshortbank igblong excr currency  banking i.year , fe robust
outreg2 using table4, ctitle(IV) bdec(3) tdec(3) rdec(3) adec(3) alpha (.01, .05, .1)e(all) word append
xtreg lkbritrealn dd regc drest dur2n expdecayn l.ic1 l.icms1  l.gold l.lmp1 l.lmp2 l.ps1 igbshortbank igblong excr currency banking i.year , fe robust
outreg2 using table4, ctitle(IV) bdec(3) tdec(3) rdec(3) adec(3) alpha (.01, .05, .1)e(all) word append


*********************************************************************************************************************************************************
***Table 5 - Estimates Accounting for Endogeneity
*********************************************************************************************************************************************************


*replace spread=spread/100
qui gen yield=newspread+igblong
local spr "newspread"
local yearfe "_Iyear_1882	_Iyear_1883	_Iyear_1884	_Iyear_1885	_Iyear_1886	_Iyear_1887	_Iyear_1888	_Iyear_1889 _Iyear_1891	_Iyear_1892	_Iyear_1893	_Iyear_1894	_Iyear_1895	_Iyear_1896	_Iyear_1897	_Iyear_1898	_Iyear_1899	_Iyear_1900	_Iyear_1901	_Iyear_1902	_Iyear_1903	_Iyear_1904	_Iyear_1905	_Iyear_1906	_Iyear_1907	_Iyear_1908	_Iyear_1909	_Iyear_1910	_Iyear_1911	_Iyear_1912"
/*replace the usual i.year command with a list of years because 1890 and 1913 were colinear with the default dummies forcing them to drop from the regression*/


xtabond2 lktotalrealn l.lktotalrealn dd regc drest dur2n expdecayn  l.ic1 l.icms1 l.gold l.lmp1 l.lmp2 l.ps1 igbshortbank igblong excr currency banking, ivstyle (_Iye*) gmmstyle( l.lktotalrealn dur2, lag(1 2))    robust nom
outreg2 using table5, ctitle(IV) bdec(3) tdec(3) rdec(3) adec(3) alpha (.01, .05, .1)e(all) drop(_Iy*) word replace
matrix vars=e(V)
xtabond2 lkbritrealn l.lkbritrealn dd regc drest dur2n expdecayn  l.ic1 l.icms1  l.gold l.lmp1 l.lmp2 l.ps1 igbshortbank igblong excr currency banking, ivstyle (_Iye*) gmmstyle( l.lkbritrealn dur2, lag(1 2))    robust nom
outreg2 using table5, ctitle(IV) bdec(3) tdec(3) rdec(3) adec(3) alpha (.01, .05, .1)e(all) drop(_Iy*) word append

global demand "(qDemand: lktotalrealn `spr' dd regc drest dur2n expdecayn l.ic1 l.icms1  l.gold l.lmp1 l.lmp2 l.ps1 excr currency banking `yearfe')"
global supply "(qSupply: `spr' dd regc drest dur2n expdecayn l.ic1 l.icms1 l.gold l.lmp1 l.lmp2 l.ps1 igbshortbank igblong excr currency banking `yearfe')"
qui reg3 $demand $supply , endog(`spr')
outreg2 using table5, ctitle(IV) bdec(3) tdec(3) rdec(3) adec(3) alpha (.01, .05, .1)e(all) drop(_Iy*) word append


*********************************************************************************************************************************************************
***Table 8 - 3SLS Estimates by Sector
*********************************************************************************************************************************************************


local yearfe "i.year"
/*here the usual command for year fixed effects can be used*/

global demand "(qDemand: lktradrealn `spr' regc drest dur2n expdecayn l.ic1 l.icms1 l.gold l.lmp1 l.lmp2 l.ps1 excr currency banking `yearfe')"
global supply "(qSupply: `spr' dd regc drest dur2n expdecayn l.ic1 l.icms1 l.gold l.lmp1 l.lmp2 l.ps1 igbshortbank igblong excr currency banking `yearfe')"
qui reg3 $demand $supply , endog(`spr')
outreg2 using table8, ctitle(IV) bdec(3) tdec(3) rdec(3) adec(3) alpha (.01, .05, .1)e(all)drop(_Iy*) word replace

global demand "(qDemand: lkntradrealn `spr' regc drest dur2n expdecayn l.ic1 l.icms1  l.gold l.lmp1 l.lmp2 l.ps1 excr currency banking `yearfe')"
global supply "(qSupply: `spr' dd regc drest dur2n expdecayn l.ic1 l.icms1 l.gold l.lmp1 l.lmp2 l.ps1 igbshortbank igblong excr currency banking `yearfe')"
qui reg3 $demand $supply , endog(`spr')
outreg2 using table8, ctitle(IV) bdec(3) tdec(3) rdec(3) adec(3) alpha (.01, .05, .1)e(all) drop(_Iy*) word append



*********************************************************************************************************************************************************
***END
*********************************************************************************************************************************************************


